###############
Getting started
###############

To get started with the Python client, reference `DataRobot's API Quickstart guide <https://docs.datarobot.com/en/docs/api/api-quickstart/api-qs.html>`_. This guide outlines how to configure your environment to use the API.

Additionally, `try a sample problem <https://docs.datarobot.com/en/docs/api/api-quickstart/tryit.html>`_ that contains Python code examples.
